@@ -13,6 +13,9 @@ class Import(NamedTuple):
     def __len__(self) -> int:
         return operator.length_hint(self.name.split("."))
 
+    def is_match_sub_packages(self, name_name) -> bool:
+        return self.name.split(".")[0] == name_name
+
 
 class ImportFrom(NamedTuple):
     lineno: int
@@ -25,6 +28,9 @@ class ImportFrom(NamedTuple):
     def __len__(self) -> int:
         return operator.length_hint(self.name.split("."))
 
+    def is_match_sub_packages(self, name_name):
+        return False
+
 
 class Name(NamedTuple):
     lineno: int
@@ -36,20 +42,14 @@ class Name(NamedTuple):
         return "." in self.name
 
     def match(self, imp: Union[Import, ImportFrom]) -> bool:
-        if self.is_attribute:
-            return self.__attribute_match(imp)
-        else:
-            return self.__name_match(imp)
-
-    def __attribute_match(self, imp: Union[Import, ImportFrom]) -> bool:
-        """if the name is a attribute."""
-        match = ".".join(self.name.split(".")[: len(imp)]) == imp.name
-        return imp.lineno < self.lineno and match
-
-    def __name_match(self, imp: Union[Import, ImportFrom]) -> bool:
-        """if the name is a normal name."""
-        match = self.name == imp.name
         if self.is_all:
-            return match
+            return self.name == imp.name
+        elif self.is_attribute:
+            return imp.lineno < self.lineno and (
+                ".".join(self.name.split(".")[: len(imp)]) == imp.name
+                or imp.is_match_sub_packages(self.name)
+            )
         else:
-            return imp.lineno < self.lineno and match
+            return (imp.lineno < self.lineno) and (
+                self.name == imp.name or imp.is_match_sub_packages(self.name)
+            )
